ExtAll<T> extension

on
  • T

Methods

animatedText({TextStyle? style, TextAlign? align, TextOverflow? overflow, int? maxLines, TextDirection? textDirection, Locale? locale, bool? softWrap, StrutStyle? strutStyle, Duration duration = const Duration(milliseconds: 100), Curve switchInCurve = Curves.easeIn, Curve switchOutCurve = Curves.easeOut, bool fade = true, bool scale = true, bool slide = false}) AnimatedSwitcher

Available on T, provided by the ExtAll extension

Returns an AnimatedSwitcher that animates text changes.
asOrNull<R>() → R?

Available on T, provided by the ExtAll extension

Safely casts this value to type R.
debug([String? tag]) → void

Available on T, provided by the ExtAll extension

Prints this value to the debug console with an optional tag.
isIn(List<T> list) bool

Available on T, provided by the ExtAll extension

Returns true if this value exists in the given list.
isNotIn(List<T> list) bool

Available on T, provided by the ExtAll extension

Returns true if this value does NOT exist in the given list.
styledText(TextStyle style, {Key? key, TextAlign? align, int? maxLines, TextOverflow? overflow, TextDirection? textDirection, Locale? locale, bool? softWrap, StrutStyle? strutStyle}) StyledText

Available on T, provided by the ExtAll extension

Wraps the string in a StyledText widget with the given style.
text({Key? key, TextStyle? style, TextAlign? align, TextOverflow? overflow, int? maxLines, TextDirection? textDirection, Locale? locale, bool? softWrap, StrutStyle? strutStyle}) Text

Available on T, provided by the ExtAll extension

Wraps the string in a standard Text widget.