isMobile property
bool
get
isMobile
Returns true if screen width is smaller than 600px (mobile).
Implementation
bool get isMobile => w < 600;
Returns true if screen width is smaller than 600px (mobile).
bool get isMobile => w < 600;