unfocus method
void
unfocus()
Unfocuses any currently focused text field in the current tree.
Implementation
void unfocus() => FocusScope.of(this).unfocus();
Unfocuses any currently focused text field in the current tree.
void unfocus() => FocusScope.of(this).unfocus();