isWeekday property
bool
get
isWeekday
Returns true if this date is on a weekday (Monday to Friday).
Implementation
bool get isWeekday => !isWeekend;
Returns true if this date is on a weekday (Monday to Friday).
bool get isWeekday => !isWeekend;