ExtMap<K, V> extension
- on
-
- Map<
K, V>
- Map<
Methods
-
getOr(
K key, V defaultValue) → V -
Available on Map<
Returns the value forK, V> , provided by the ExtMap extensionkeyif it exists and is not null, otherwise returnsdefaultValue. -
has(
K key) → bool -
Available on Map<
Checks if the map contains a non-null value for the givenK, V> , provided by the ExtMap extensionkey. -
string(
K key) → String -
Available on Map<
Returns the string representation of the value associated withK, V> , provided by the ExtMap extensionkey. -
whereKey(
bool test(K key)) → Map< K, V> -
Available on Map<
Returns a new map containing only the entries where the key satisfies theK, V> , provided by the ExtMap extensiontestpredicate. -
whereValue(
bool test(V v)) → Map< K, V> -
Available on Map<
Returns a new map containing only the entries where the value satisfies theK, V> , provided by the ExtMap extensiontestpredicate.