toIntOrNull property
int?
get
toIntOrNull
Parses this string as an integer, or returns null if invalid.
Implementation
int? get toIntOrNull => int.tryParse(trim());
Parses this string as an integer, or returns null if invalid.
int? get toIntOrNull => int.tryParse(trim());