ExtColor extension

on

Methods

darken([double amount = 0.1]) Color

Available on Color, provided by the ExtColor extension

Returns a darker version of this color by amount (between 0.0 and 1.0).
lighten([double amount = 0.1]) Color

Available on Color, provided by the ExtColor extension

Returns a lighter version of this color by amount (between 0.0 and 1.0).
toHex({bool leadingHashSign = true, bool includeAlpha = false}) String

Available on Color, provided by the ExtColor extension

Converts this color to a hex string (e.g. "#RRGGBB" or "#AARRGGBB").