ShimmerWidget class

A widget that applies a shimmering loading effect to its child.

Inheritance
Available extensions

Constructors

ShimmerWidget({Key? key, required Widget child, bool isLoading = true, Color baseColor = const Color(0xFFE0E0E0), Color highlightColor = const Color(0xFFF5F5F5), Duration duration = const Duration(milliseconds: 1500)})
const

Properties

baseColor Color
The base color of the shimmer gradient.
final
child Widget
The widget over which to draw the shimmer effect.
final
duration Duration
The duration of the shimmer animation cycle.
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color
The highlight color of the shimmer gradient.
final
isLoading bool
Whether the shimmer animation is active.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

align(Alignment alignment) Widget

Available on Widget, provided by the ExtWidget extension

Aligns this widget with the given alignment.
aspectRatio(double ratio) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in an AspectRatio with the given ratio.
blurred(double sigmaX, double sigmaY, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Applies a blur effect to this widget with the given sigmaX and sigmaY.
card({Color? color, Color? shadowColor, Color? surfaceTintColor, double? elevation, ShapeBorder? shape, bool borderOnForeground = true, EdgeInsetsGeometry? margin, Clip? clipBehavior, bool semanticContainer = true}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Card.
center() Widget

Available on Widget, provided by the ExtWidget extension

Centers this widget.
clipped([BorderRadius? borderRadius]) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a ClipRRect with the given borderRadius. If borderRadius is not provided, a circular radius of 8.0 is used. Example:
container({Color? color, DecorationImage? image, BoxBorder? border, BorderRadiusGeometry? borderRadius, List<BoxShadow>? boxShadow, Gradient? gradient, BlendMode? backgroundBlendMode, BoxShape shape = BoxShape.rectangle, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? width, double? height, BoxConstraints? constraints, AlignmentGeometry? alignment, Clip clipBehavior = Clip.none}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Container with the given decoration parameters.
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ShimmerWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget with Expanded with optional flex.
expandedIf(bool condition, {int flex = 1}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget with Expanded if condition is true, otherwise returns this widget.
faded(double opacity, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Fades this widget to the given opacity. Animate if opacity changes.
fadedIn([Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Fades this widget in with the given duration.
fadedOut([Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Fades this widget out with the given duration.
flexible({int flex = 1, FlexFit fit = FlexFit.loose}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget with Flexible with optional flex and fit.
hero(Object tag, {CreateRectTween? createRectTween, HeroFlightShuttleBuilder? flightShuttleBuilder, HeroPlaceholderBuilder? placeholderBuilder, bool transitionOnUserGestures = false}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Hero with the given tag.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offstage(bool isOffstage) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget with Offstage based on isOffstage.
onLongPress([VoidCallback? callback]) Widget

Available on Widget, provided by the ExtWidget extension

Adds an onLongPress gesture using InkWell over a transparent Material.
onTap([VoidCallback? callback]) Widget

Available on Widget, provided by the ExtWidget extension

Adds an onTap gesture using InkWell over a transparent Material.
positioned({double? left, double? top, double? right, double? bottom}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Positioned with the given parameters.
positionedFill({double? left, double? top, double? right, double? bottom}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Positioned.fill with the given parameters.
rotated(double degree, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Rotates this widget by degree degrees. Animate if degree changes.
safe() Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a SafeArea.
scaled(double scale, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Scales this widget by scale. Animate if scale changes.
scrollable({Axis scrollDirection = Axis.vertical, bool reverse = false, EdgeInsetsGeometry? padding, bool? primary, ScrollPhysics? physics, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, Clip clipBehavior = Clip.hardEdge, String? restorationId, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a SingleChildScrollView.
shimmer({bool isLoading = true, Color baseColor = const Color(0xFFE0E0E0), Color highlightColor = const Color(0xFFF5F5F5), Duration duration = const Duration(milliseconds: 1500)}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a shimmer loading effect when isLoading is true.
sized({double? width, double? height}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a SizedBox with the given width and/or height.
sizedSquare(double size) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a square SizedBox with both width and height set to size.
sliver() Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a SliverToBoxAdapter, useful for slivers in CustomScrollView.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
tooltip(String message, {Decoration? decoration, BoxConstraints? constraints, EdgeInsetsGeometry? padding, TextStyle? textStyle, Duration? waitDuration, Duration? showDuration}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Tooltip.
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
translated(double x, double y, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Translates this widget by offset. Animate if offset changes.
unfocusOnTap() Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a GestureDetector that unfocuses the current keyboard/focus on tap.
visibility(bool isVisible) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget with Visibility based on isVisible.
visibilityAnimated(bool isVisible, [Duration duration = const Duration(milliseconds: 300)]) Widget

Available on Widget, provided by the ExtWidget extension

Animates the visibility of this widget based on isVisible.
withPadding({double? all, double? horizontal, double? vertical, double? top, double? bottom, double? left, double? right}) Widget

Available on Widget, provided by the ExtWidget extension

Wraps this widget in a Padding with the given values. If all is provided, it overrides other parameters. Example:

Operators

operator *(int n) List<Widget>

Available on Widget, provided by the ExtWidget extension

Creates a list containing n copies of this widget.
operator ==(Object other) bool
The equality operator.
inherited