ExtContext extension
- on
Properties
- backgroundColor → Color
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access scaffold background color from theme.no setter - colorScheme → ColorScheme
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access the current ColorScheme.no setter - h → double
-
Available on BuildContext, provided by the ExtContext extension
Screen height in logical pixels.no setter - isCurrent → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif this route is the current active route.no setter - isDarkMode → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif current brightness is dark.no setter - isDesktop → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif screen width is 1024px or larger (desktop).no setter - isKeyboardOpen → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif on-screen keyboard is visible.no setter - isLandscape → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif screen orientation is landscape.no setter - isMobile → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif screen width is smaller than 600px (mobile).no setter - isPortrait → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif screen orientation is portrait.no setter - isTablet → bool
-
Available on BuildContext, provided by the ExtContext extension
Returnstrueif screen width is between 600px and 1024px (tablet).no setter - media → MediaQueryData
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access MediaQueryData from the current context.no setter -
Available on BuildContext, provided by the ExtContext extension
Shortcut to access the nearest NavigatorState.no setter - padding → EdgeInsets
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access padding from MediaQueryData.no setter - primaryColor → Color
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access primary color from theme.no setter - textTheme → TextTheme
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access the current TextTheme.no setter - theme → ThemeData
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access the current ThemeData.no setter - viewInsets → EdgeInsets
-
Available on BuildContext, provided by the ExtContext extension
Shortcut to access view insets from MediaQueryData.no setter - w → double
-
Available on BuildContext, provided by the ExtContext extension
Screen width in logical pixels.no setter
Methods
-
allTo<
T> (Widget page, {PageTransitionType? type}) → Future< T?> -
Available on BuildContext, provided by the ExtContext extension
Pushes a new page and removes all previous routes. -
back<
T> ([T? result]) → Future< void> -
Available on BuildContext, provided by the ExtContext extension
Pops the current route if possible. -
backTo(
Widget page) → Future -
Available on BuildContext, provided by the ExtContext extension
Pops routes until the givenpageroute name is reached. -
goTo<
T> (Widget page, {bool safe = true, PageTransitionType? type}) → Future< T?> -
Available on BuildContext, provided by the ExtContext extension
Pushes a new page onto the navigation stack. -
replaceTo<
T, TO> (Widget page, {bool safe = false, PageTransitionType? type}) → Future< T?> -
Available on BuildContext, provided by the ExtContext extension
Replaces the current route with a new page. -
responsive<
T> ({required T mobile, T? tablet, T? desktop}) → T -
Available on BuildContext, provided by the ExtContext extension
Returns a responsive value based on screen width. -
showModalSheet<
T> ({required Widget child, bool isDismissible = true, bool enableDrag = true, bool isScrollControlled = false, Color? backgroundColor, double? elevation, ShapeBorder? shape, Clip? clipBehavior}) → Future< T?> -
Available on BuildContext, provided by the ExtContext extension
Displays a modal bottom sheet with the givenchild. -
showPopUp<
T> ({String? title, required String message, String? confirmText, String? cancelText, VoidCallback? onConfirm, VoidCallback? onCancel, bool? dismissible, bool? center, Color? confirmColor, Color? cancelColor, TextStyle? titleStyle, TextStyle? messageStyle, TextStyle? confirmStyle, TextStyle? cancelStyle}) → Future< T?> -
Available on BuildContext, provided by the ExtContext extension
Displays a customizable popup dialog. -
snack(
String message, {bool success = true, bool clearAll = true, int ms = 2000, String? actionText, TextStyle? messageStyle, TextStyle? actionStyle, VoidCallback? onAction, bool zeroMargin = true, Color? textColor}) → void -
Available on BuildContext, provided by the ExtContext extension
Displays a customizable SnackBar. -
snackException(
dynamic e, {bool clearAll = true, int ms = 2000, String? actionText, VoidCallback? onAction, bool zeroMargin = true, Color? textColor}) → void -
Available on BuildContext, provided by the ExtContext extension
Displays an error snack bar from an exception. -
snackInfinite(
String message, {bool success = true, bool clearAll = true, String? actionText, VoidCallback? onAction, bool zeroMargin = true, Color? textColor}) → void -
Available on BuildContext, provided by the ExtContext extension
Displays a snack bar with an almost infinite duration. -
unfocus(
) → void -
Available on BuildContext, provided by the ExtContext extension
Unfocuses any currently focused text field in the current tree. -
validateWithSnack(
List< bool> conditions, List<String> errors) → bool -
Available on BuildContext, provided by the ExtContext extension
Validates multiple booleanconditions.