ExtDate extension
- on
Properties
- age → int
-
Available on DateTime, provided by the ExtDate extension
Calculates age in full years from this birth date.no setter - endOfDay → DateTime
-
Available on DateTime, provided by the ExtDate extension
Returns the end of this day (23:59:59.999).no setter - isFuture → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date is in the future.no setter - isPast → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date is in the past.no setter - isToday → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date represents today.no setter - isTomorrow → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date represents tomorrow.no setter - isWeekday → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date is on a weekday (Monday to Friday).no setter - isWeekend → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date is on a weekend (Saturday or Sunday).no setter - isYesterday → bool
-
Available on DateTime, provided by the ExtDate extension
Returnstrueif this date represents yesterday.no setter - startOfDay → DateTime
-
Available on DateTime, provided by the ExtDate extension
Returns the start of this day (00:00:00.000).no setter -
week
→ List<
DateTime> -
Available on DateTime, provided by the ExtDate extension
Returns the start and end dates of the current week.no setter
Methods
-
addDays(
int days) → DateTime -
Available on DateTime, provided by the ExtDate extension
Addsdaysdays to this date. -
ago(
{String locale = "en"}) → String - Returns a human-readable relative time string.
-
format(
{String pattern = "dd MMM yyyy", String? locale}) → String -
Available on DateTime, provided by the ExtDate extension
Formats this date using the givenpatternandlocale. -
formatMY(
[bool fullMonth = true]) → String - Formats this date as "Month Year".
-
isSameDate(
DateTime dateTime) → bool -
Available on DateTime, provided by the ExtDate extension
Checks whether this date has the same day and month as the givendateTime. -
isSameDay(
DateTime other) → bool -
Available on DateTime, provided by the ExtDate extension
Checks whether this date occurs on the same calendar day asother, including year. -
subDays(
int days) → DateTime -
Available on DateTime, provided by the ExtDate extension
Subtractsdaysdays from this date.